@@ -1,5 +1,7 @@
 """
-Main interface for dataexchange service type definitions.
+Type annotations for dataexchange service type definitions.
+
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -13,6 +15,16 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
+from .literals import (
+    Code,
+    JobErrorLimitName,
+    JobErrorResourceTypes,
+    Origin,
+    ServerSideEncryptionTypes,
+    State,
+    TypeType,
+)
+
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
@@ -28,6 +40,9 @@ __all__ = (
     "AssetDetailsTypeDef",
     "AssetEntryTypeDef",
     "AssetSourceEntryTypeDef",
+    "CreateDataSetResponseTypeDef",
+    "CreateJobResponseTypeDef",
+    "CreateRevisionResponseTypeDef",
     "DataSetEntryTypeDef",
     "DetailsTypeDef",
     "ExportAssetToSignedUrlRequestDetailsTypeDef",
@@ -37,6 +52,10 @@ __all__ = (
     "ExportRevisionsToS3RequestDetailsTypeDef",
     "ExportRevisionsToS3ResponseDetailsTypeDef",
     "ExportServerSideEncryptionTypeDef",
+    "GetAssetResponseTypeDef",
+    "GetDataSetResponseTypeDef",
+    "GetJobResponseTypeDef",
+    "GetRevisionResponseTypeDef",
     "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
     "ImportAssetFromSignedUrlRequestDetailsTypeDef",
     "ImportAssetFromSignedUrlResponseDetailsTypeDef",
@@ -44,35 +63,36 @@ __all__ = (
     "ImportAssetsFromS3ResponseDetailsTypeDef",
     "JobEntryTypeDef",
     "JobErrorTypeDef",
-    "OriginDetailsTypeDef",
-    "ResponseDetailsTypeDef",
-    "RevisionDestinationEntryTypeDef",
-    "RevisionEntryTypeDef",
-    "S3SnapshotAssetTypeDef",
-    "CreateDataSetResponseTypeDef",
-    "CreateJobResponseTypeDef",
-    "CreateRevisionResponseTypeDef",
-    "GetAssetResponseTypeDef",
-    "GetDataSetResponseTypeDef",
-    "GetJobResponseTypeDef",
-    "GetRevisionResponseTypeDef",
     "ListDataSetRevisionsResponseTypeDef",
     "ListDataSetsResponseTypeDef",
     "ListJobsResponseTypeDef",
     "ListRevisionAssetsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "OriginDetailsTypeDef",
     "PaginatorConfigTypeDef",
     "RequestDetailsTypeDef",
+    "ResponseDetailsTypeDef",
+    "RevisionDestinationEntryTypeDef",
+    "RevisionEntryTypeDef",
+    "S3SnapshotAssetTypeDef",
     "UpdateAssetResponseTypeDef",
     "UpdateDataSetResponseTypeDef",
     "UpdateRevisionResponseTypeDef",
 )
 
 _RequiredAssetDestinationEntryTypeDef = TypedDict(
-    "_RequiredAssetDestinationEntryTypeDef", {"AssetId": str, "Bucket": str}
+    "_RequiredAssetDestinationEntryTypeDef",
+    {
+        "AssetId": str,
+        "Bucket": str,
+    },
 )
 _OptionalAssetDestinationEntryTypeDef = TypedDict(
-    "_OptionalAssetDestinationEntryTypeDef", {"Key": str}, total=False
+    "_OptionalAssetDestinationEntryTypeDef",
+    {
+        "Key": str,
+    },
+    total=False,
 )
 
 
@@ -83,7 +103,11 @@ class AssetDestinationEntryTypeDef(
 
 
 AssetDetailsTypeDef = TypedDict(
-    "AssetDetailsTypeDef", {"S3SnapshotAsset": "S3SnapshotAssetTypeDef"}, total=False
+    "AssetDetailsTypeDef",
+    {
+        "S3SnapshotAsset": "S3SnapshotAssetTypeDef",
+    },
+    total=False,
 )
 
 _RequiredAssetEntryTypeDef = TypedDict(
@@ -100,14 +124,75 @@ _RequiredAssetEntryTypeDef = TypedDict(
         "UpdatedAt": datetime,
     },
 )
-_OptionalAssetEntryTypeDef = TypedDict("_OptionalAssetEntryTypeDef", {"SourceId": str}, total=False)
+_OptionalAssetEntryTypeDef = TypedDict(
+    "_OptionalAssetEntryTypeDef",
+    {
+        "SourceId": str,
+    },
+    total=False,
+)
 
 
 class AssetEntryTypeDef(_RequiredAssetEntryTypeDef, _OptionalAssetEntryTypeDef):
     pass
 
 
-AssetSourceEntryTypeDef = TypedDict("AssetSourceEntryTypeDef", {"Bucket": str, "Key": str})
+AssetSourceEntryTypeDef = TypedDict(
+    "AssetSourceEntryTypeDef",
+    {
+        "Bucket": str,
+        "Key": str,
+    },
+)
+
+CreateDataSetResponseTypeDef = TypedDict(
+    "CreateDataSetResponseTypeDef",
+    {
+        "Arn": str,
+        "AssetType": Literal["S3_SNAPSHOT"],
+        "CreatedAt": datetime,
+        "Description": str,
+        "Id": str,
+        "Name": str,
+        "Origin": Origin,
+        "OriginDetails": "OriginDetailsTypeDef",
+        "SourceId": str,
+        "Tags": Dict[str, str],
+        "UpdatedAt": datetime,
+    },
+    total=False,
+)
+
+CreateJobResponseTypeDef = TypedDict(
+    "CreateJobResponseTypeDef",
+    {
+        "Arn": str,
+        "CreatedAt": datetime,
+        "Details": "ResponseDetailsTypeDef",
+        "Errors": List["JobErrorTypeDef"],
+        "Id": str,
+        "State": State,
+        "Type": TypeType,
+        "UpdatedAt": datetime,
+    },
+    total=False,
+)
+
+CreateRevisionResponseTypeDef = TypedDict(
+    "CreateRevisionResponseTypeDef",
+    {
+        "Arn": str,
+        "Comment": str,
+        "CreatedAt": datetime,
+        "DataSetId": str,
+        "Finalized": bool,
+        "Id": str,
+        "SourceId": str,
+        "Tags": Dict[str, str],
+        "UpdatedAt": datetime,
+    },
+    total=False,
+)
 
 _RequiredDataSetEntryTypeDef = TypedDict(
     "_RequiredDataSetEntryTypeDef",
@@ -118,13 +203,16 @@ _RequiredDataSetEntryTypeDef = TypedDict(
         "Description": str,
         "Id": str,
         "Name": str,
-        "Origin": Literal["OWNED", "ENTITLED"],
+        "Origin": Origin,
         "UpdatedAt": datetime,
     },
 )
 _OptionalDataSetEntryTypeDef = TypedDict(
     "_OptionalDataSetEntryTypeDef",
-    {"OriginDetails": "OriginDetailsTypeDef", "SourceId": str},
+    {
+        "OriginDetails": "OriginDetailsTypeDef",
+        "SourceId": str,
+    },
     total=False,
 )
 
@@ -144,16 +232,27 @@ DetailsTypeDef = TypedDict(
 
 ExportAssetToSignedUrlRequestDetailsTypeDef = TypedDict(
     "ExportAssetToSignedUrlRequestDetailsTypeDef",
-    {"AssetId": str, "DataSetId": str, "RevisionId": str},
+    {
+        "AssetId": str,
+        "DataSetId": str,
+        "RevisionId": str,
+    },
 )
 
 _RequiredExportAssetToSignedUrlResponseDetailsTypeDef = TypedDict(
     "_RequiredExportAssetToSignedUrlResponseDetailsTypeDef",
-    {"AssetId": str, "DataSetId": str, "RevisionId": str},
+    {
+        "AssetId": str,
+        "DataSetId": str,
+        "RevisionId": str,
+    },
 )
 _OptionalExportAssetToSignedUrlResponseDetailsTypeDef = TypedDict(
     "_OptionalExportAssetToSignedUrlResponseDetailsTypeDef",
-    {"SignedUrl": str, "SignedUrlExpiresAt": datetime},
+    {
+        "SignedUrl": str,
+        "SignedUrlExpiresAt": datetime,
+    },
     total=False,
 )
 
@@ -175,7 +274,9 @@ _RequiredExportAssetsToS3RequestDetailsTypeDef = TypedDict(
 )
 _OptionalExportAssetsToS3RequestDetailsTypeDef = TypedDict(
     "_OptionalExportAssetsToS3RequestDetailsTypeDef",
-    {"Encryption": "ExportServerSideEncryptionTypeDef"},
+    {
+        "Encryption": "ExportServerSideEncryptionTypeDef",
+    },
     total=False,
 )
 
@@ -196,7 +297,9 @@ _RequiredExportAssetsToS3ResponseDetailsTypeDef = TypedDict(
 )
 _OptionalExportAssetsToS3ResponseDetailsTypeDef = TypedDict(
     "_OptionalExportAssetsToS3ResponseDetailsTypeDef",
-    {"Encryption": "ExportServerSideEncryptionTypeDef"},
+    {
+        "Encryption": "ExportServerSideEncryptionTypeDef",
+    },
     total=False,
 )
 
@@ -209,11 +312,16 @@ class ExportAssetsToS3ResponseDetailsTypeDef(
 
 _RequiredExportRevisionsToS3RequestDetailsTypeDef = TypedDict(
     "_RequiredExportRevisionsToS3RequestDetailsTypeDef",
-    {"DataSetId": str, "RevisionDestinations": List["RevisionDestinationEntryTypeDef"]},
+    {
+        "DataSetId": str,
+        "RevisionDestinations": List["RevisionDestinationEntryTypeDef"],
+    },
 )
 _OptionalExportRevisionsToS3RequestDetailsTypeDef = TypedDict(
     "_OptionalExportRevisionsToS3RequestDetailsTypeDef",
-    {"Encryption": "ExportServerSideEncryptionTypeDef"},
+    {
+        "Encryption": "ExportServerSideEncryptionTypeDef",
+    },
     total=False,
 )
 
@@ -227,11 +335,16 @@ class ExportRevisionsToS3RequestDetailsTypeDef(
 
 _RequiredExportRevisionsToS3ResponseDetailsTypeDef = TypedDict(
     "_RequiredExportRevisionsToS3ResponseDetailsTypeDef",
-    {"DataSetId": str, "RevisionDestinations": List["RevisionDestinationEntryTypeDef"]},
+    {
+        "DataSetId": str,
+        "RevisionDestinations": List["RevisionDestinationEntryTypeDef"],
+    },
 )
 _OptionalExportRevisionsToS3ResponseDetailsTypeDef = TypedDict(
     "_OptionalExportRevisionsToS3ResponseDetailsTypeDef",
-    {"Encryption": "ExportServerSideEncryptionTypeDef"},
+    {
+        "Encryption": "ExportServerSideEncryptionTypeDef",
+    },
     total=False,
 )
 
@@ -244,10 +357,17 @@ class ExportRevisionsToS3ResponseDetailsTypeDef(
 
 
 _RequiredExportServerSideEncryptionTypeDef = TypedDict(
-    "_RequiredExportServerSideEncryptionTypeDef", {"Type": Literal["aws:kms", "AES256"]}
+    "_RequiredExportServerSideEncryptionTypeDef",
+    {
+        "Type": ServerSideEncryptionTypes,
+    },
 )
 _OptionalExportServerSideEncryptionTypeDef = TypedDict(
-    "_OptionalExportServerSideEncryptionTypeDef", {"KmsKeyArn": str}, total=False
+    "_OptionalExportServerSideEncryptionTypeDef",
+    {
+        "KmsKeyArn": str,
+    },
+    total=False,
 )
 
 
@@ -257,202 +377,6 @@ class ExportServerSideEncryptionTypeDef(
     pass
 
 
-ImportAssetFromSignedUrlJobErrorDetailsTypeDef = TypedDict(
-    "ImportAssetFromSignedUrlJobErrorDetailsTypeDef", {"AssetName": str}
-)
-
-ImportAssetFromSignedUrlRequestDetailsTypeDef = TypedDict(
-    "ImportAssetFromSignedUrlRequestDetailsTypeDef",
-    {"AssetName": str, "DataSetId": str, "Md5Hash": str, "RevisionId": str},
-)
-
-_RequiredImportAssetFromSignedUrlResponseDetailsTypeDef = TypedDict(
-    "_RequiredImportAssetFromSignedUrlResponseDetailsTypeDef",
-    {"AssetName": str, "DataSetId": str, "RevisionId": str},
-)
-_OptionalImportAssetFromSignedUrlResponseDetailsTypeDef = TypedDict(
-    "_OptionalImportAssetFromSignedUrlResponseDetailsTypeDef",
-    {"Md5Hash": str, "SignedUrl": str, "SignedUrlExpiresAt": datetime},
-    total=False,
-)
-
-
-class ImportAssetFromSignedUrlResponseDetailsTypeDef(
-    _RequiredImportAssetFromSignedUrlResponseDetailsTypeDef,
-    _OptionalImportAssetFromSignedUrlResponseDetailsTypeDef,
-):
-    pass
-
-
-ImportAssetsFromS3RequestDetailsTypeDef = TypedDict(
-    "ImportAssetsFromS3RequestDetailsTypeDef",
-    {"AssetSources": List["AssetSourceEntryTypeDef"], "DataSetId": str, "RevisionId": str},
-)
-
-ImportAssetsFromS3ResponseDetailsTypeDef = TypedDict(
-    "ImportAssetsFromS3ResponseDetailsTypeDef",
-    {"AssetSources": List["AssetSourceEntryTypeDef"], "DataSetId": str, "RevisionId": str},
-)
-
-_RequiredJobEntryTypeDef = TypedDict(
-    "_RequiredJobEntryTypeDef",
-    {
-        "Arn": str,
-        "CreatedAt": datetime,
-        "Details": "ResponseDetailsTypeDef",
-        "Id": str,
-        "State": Literal["WAITING", "IN_PROGRESS", "ERROR", "COMPLETED", "CANCELLED", "TIMED_OUT"],
-        "Type": Literal[
-            "IMPORT_ASSETS_FROM_S3",
-            "IMPORT_ASSET_FROM_SIGNED_URL",
-            "EXPORT_ASSETS_TO_S3",
-            "EXPORT_ASSET_TO_SIGNED_URL",
-            "EXPORT_REVISIONS_TO_S3",
-        ],
-        "UpdatedAt": datetime,
-    },
-)
-_OptionalJobEntryTypeDef = TypedDict(
-    "_OptionalJobEntryTypeDef", {"Errors": List["JobErrorTypeDef"]}, total=False
-)
-
-
-class JobEntryTypeDef(_RequiredJobEntryTypeDef, _OptionalJobEntryTypeDef):
-    pass
-
-
-_RequiredJobErrorTypeDef = TypedDict(
-    "_RequiredJobErrorTypeDef",
-    {
-        "Code": Literal[
-            "ACCESS_DENIED_EXCEPTION",
-            "INTERNAL_SERVER_EXCEPTION",
-            "MALWARE_DETECTED",
-            "RESOURCE_NOT_FOUND_EXCEPTION",
-            "SERVICE_QUOTA_EXCEEDED_EXCEPTION",
-            "VALIDATION_EXCEPTION",
-            "MALWARE_SCAN_ENCRYPTED_FILE",
-        ],
-        "Message": str,
-    },
-)
-_OptionalJobErrorTypeDef = TypedDict(
-    "_OptionalJobErrorTypeDef",
-    {
-        "Details": "DetailsTypeDef",
-        "LimitName": Literal["Assets per revision", "Asset size in GB"],
-        "LimitValue": float,
-        "ResourceId": str,
-        "ResourceType": Literal["REVISION", "ASSET"],
-    },
-    total=False,
-)
-
-
-class JobErrorTypeDef(_RequiredJobErrorTypeDef, _OptionalJobErrorTypeDef):
-    pass
-
-
-OriginDetailsTypeDef = TypedDict("OriginDetailsTypeDef", {"ProductId": str})
-
-ResponseDetailsTypeDef = TypedDict(
-    "ResponseDetailsTypeDef",
-    {
-        "ExportAssetToSignedUrl": "ExportAssetToSignedUrlResponseDetailsTypeDef",
-        "ExportAssetsToS3": "ExportAssetsToS3ResponseDetailsTypeDef",
-        "ExportRevisionsToS3": "ExportRevisionsToS3ResponseDetailsTypeDef",
-        "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlResponseDetailsTypeDef",
-        "ImportAssetsFromS3": "ImportAssetsFromS3ResponseDetailsTypeDef",
-    },
-    total=False,
-)
-
-_RequiredRevisionDestinationEntryTypeDef = TypedDict(
-    "_RequiredRevisionDestinationEntryTypeDef", {"Bucket": str, "RevisionId": str}
-)
-_OptionalRevisionDestinationEntryTypeDef = TypedDict(
-    "_OptionalRevisionDestinationEntryTypeDef", {"KeyPattern": str}, total=False
-)
-
-
-class RevisionDestinationEntryTypeDef(
-    _RequiredRevisionDestinationEntryTypeDef, _OptionalRevisionDestinationEntryTypeDef
-):
-    pass
-
-
-_RequiredRevisionEntryTypeDef = TypedDict(
-    "_RequiredRevisionEntryTypeDef",
-    {"Arn": str, "CreatedAt": datetime, "DataSetId": str, "Id": str, "UpdatedAt": datetime},
-)
-_OptionalRevisionEntryTypeDef = TypedDict(
-    "_OptionalRevisionEntryTypeDef",
-    {"Comment": str, "Finalized": bool, "SourceId": str},
-    total=False,
-)
-
-
-class RevisionEntryTypeDef(_RequiredRevisionEntryTypeDef, _OptionalRevisionEntryTypeDef):
-    pass
-
-
-S3SnapshotAssetTypeDef = TypedDict("S3SnapshotAssetTypeDef", {"Size": float})
-
-CreateDataSetResponseTypeDef = TypedDict(
-    "CreateDataSetResponseTypeDef",
-    {
-        "Arn": str,
-        "AssetType": Literal["S3_SNAPSHOT"],
-        "CreatedAt": datetime,
-        "Description": str,
-        "Id": str,
-        "Name": str,
-        "Origin": Literal["OWNED", "ENTITLED"],
-        "OriginDetails": "OriginDetailsTypeDef",
-        "SourceId": str,
-        "Tags": Dict[str, str],
-        "UpdatedAt": datetime,
-    },
-    total=False,
-)
-
-CreateJobResponseTypeDef = TypedDict(
-    "CreateJobResponseTypeDef",
-    {
-        "Arn": str,
-        "CreatedAt": datetime,
-        "Details": "ResponseDetailsTypeDef",
-        "Errors": List["JobErrorTypeDef"],
-        "Id": str,
-        "State": Literal["WAITING", "IN_PROGRESS", "ERROR", "COMPLETED", "CANCELLED", "TIMED_OUT"],
-        "Type": Literal[
-            "IMPORT_ASSETS_FROM_S3",
-            "IMPORT_ASSET_FROM_SIGNED_URL",
-            "EXPORT_ASSETS_TO_S3",
-            "EXPORT_ASSET_TO_SIGNED_URL",
-            "EXPORT_REVISIONS_TO_S3",
-        ],
-        "UpdatedAt": datetime,
-    },
-    total=False,
-)
-
-CreateRevisionResponseTypeDef = TypedDict(
-    "CreateRevisionResponseTypeDef",
-    {
-        "Arn": str,
-        "Comment": str,
-        "CreatedAt": datetime,
-        "DataSetId": str,
-        "Finalized": bool,
-        "Id": str,
-        "SourceId": str,
-        "Tags": Dict[str, str],
-        "UpdatedAt": datetime,
-    },
-    total=False,
-)
-
 GetAssetResponseTypeDef = TypedDict(
     "GetAssetResponseTypeDef",
     {
@@ -479,7 +403,7 @@ GetDataSetResponseTypeDef = TypedDict(
         "Description": str,
         "Id": str,
         "Name": str,
-        "Origin": Literal["OWNED", "ENTITLED"],
+        "Origin": Origin,
         "OriginDetails": "OriginDetailsTypeDef",
         "SourceId": str,
         "Tags": Dict[str, str],
@@ -496,14 +420,8 @@ GetJobResponseTypeDef = TypedDict(
         "Details": "ResponseDetailsTypeDef",
         "Errors": List["JobErrorTypeDef"],
         "Id": str,
-        "State": Literal["WAITING", "IN_PROGRESS", "ERROR", "COMPLETED", "CANCELLED", "TIMED_OUT"],
-        "Type": Literal[
-            "IMPORT_ASSETS_FROM_S3",
-            "IMPORT_ASSET_FROM_SIGNED_URL",
-            "EXPORT_ASSETS_TO_S3",
-            "EXPORT_ASSET_TO_SIGNED_URL",
-            "EXPORT_REVISIONS_TO_S3",
-        ],
+        "State": State,
+        "Type": TypeType,
         "UpdatedAt": datetime,
     },
     total=False,
@@ -525,34 +443,175 @@ GetRevisionResponseTypeDef = TypedDict(
     total=False,
 )
 
+ImportAssetFromSignedUrlJobErrorDetailsTypeDef = TypedDict(
+    "ImportAssetFromSignedUrlJobErrorDetailsTypeDef",
+    {
+        "AssetName": str,
+    },
+)
+
+ImportAssetFromSignedUrlRequestDetailsTypeDef = TypedDict(
+    "ImportAssetFromSignedUrlRequestDetailsTypeDef",
+    {
+        "AssetName": str,
+        "DataSetId": str,
+        "Md5Hash": str,
+        "RevisionId": str,
+    },
+)
+
+_RequiredImportAssetFromSignedUrlResponseDetailsTypeDef = TypedDict(
+    "_RequiredImportAssetFromSignedUrlResponseDetailsTypeDef",
+    {
+        "AssetName": str,
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+_OptionalImportAssetFromSignedUrlResponseDetailsTypeDef = TypedDict(
+    "_OptionalImportAssetFromSignedUrlResponseDetailsTypeDef",
+    {
+        "Md5Hash": str,
+        "SignedUrl": str,
+        "SignedUrlExpiresAt": datetime,
+    },
+    total=False,
+)
+
+
+class ImportAssetFromSignedUrlResponseDetailsTypeDef(
+    _RequiredImportAssetFromSignedUrlResponseDetailsTypeDef,
+    _OptionalImportAssetFromSignedUrlResponseDetailsTypeDef,
+):
+    pass
+
+
+ImportAssetsFromS3RequestDetailsTypeDef = TypedDict(
+    "ImportAssetsFromS3RequestDetailsTypeDef",
+    {
+        "AssetSources": List["AssetSourceEntryTypeDef"],
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+
+ImportAssetsFromS3ResponseDetailsTypeDef = TypedDict(
+    "ImportAssetsFromS3ResponseDetailsTypeDef",
+    {
+        "AssetSources": List["AssetSourceEntryTypeDef"],
+        "DataSetId": str,
+        "RevisionId": str,
+    },
+)
+
+_RequiredJobEntryTypeDef = TypedDict(
+    "_RequiredJobEntryTypeDef",
+    {
+        "Arn": str,
+        "CreatedAt": datetime,
+        "Details": "ResponseDetailsTypeDef",
+        "Id": str,
+        "State": State,
+        "Type": TypeType,
+        "UpdatedAt": datetime,
+    },
+)
+_OptionalJobEntryTypeDef = TypedDict(
+    "_OptionalJobEntryTypeDef",
+    {
+        "Errors": List["JobErrorTypeDef"],
+    },
+    total=False,
+)
+
+
+class JobEntryTypeDef(_RequiredJobEntryTypeDef, _OptionalJobEntryTypeDef):
+    pass
+
+
+_RequiredJobErrorTypeDef = TypedDict(
+    "_RequiredJobErrorTypeDef",
+    {
+        "Code": Code,
+        "Message": str,
+    },
+)
+_OptionalJobErrorTypeDef = TypedDict(
+    "_OptionalJobErrorTypeDef",
+    {
+        "Details": "DetailsTypeDef",
+        "LimitName": JobErrorLimitName,
+        "LimitValue": float,
+        "ResourceId": str,
+        "ResourceType": JobErrorResourceTypes,
+    },
+    total=False,
+)
+
+
+class JobErrorTypeDef(_RequiredJobErrorTypeDef, _OptionalJobErrorTypeDef):
+    pass
+
+
 ListDataSetRevisionsResponseTypeDef = TypedDict(
     "ListDataSetRevisionsResponseTypeDef",
-    {"NextToken": str, "Revisions": List["RevisionEntryTypeDef"]},
+    {
+        "NextToken": str,
+        "Revisions": List["RevisionEntryTypeDef"],
+    },
     total=False,
 )
 
 ListDataSetsResponseTypeDef = TypedDict(
     "ListDataSetsResponseTypeDef",
-    {"DataSets": List["DataSetEntryTypeDef"], "NextToken": str},
+    {
+        "DataSets": List["DataSetEntryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListJobsResponseTypeDef = TypedDict(
-    "ListJobsResponseTypeDef", {"Jobs": List["JobEntryTypeDef"], "NextToken": str}, total=False
+    "ListJobsResponseTypeDef",
+    {
+        "Jobs": List["JobEntryTypeDef"],
+        "NextToken": str,
+    },
+    total=False,
 )
 
 ListRevisionAssetsResponseTypeDef = TypedDict(
     "ListRevisionAssetsResponseTypeDef",
-    {"Assets": List["AssetEntryTypeDef"], "NextToken": str},
+    {
+        "Assets": List["AssetEntryTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+OriginDetailsTypeDef = TypedDict(
+    "OriginDetailsTypeDef",
+    {
+        "ProductId": str,
+    },
 )
 
 PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
 )
 
 RequestDetailsTypeDef = TypedDict(
@@ -567,6 +626,72 @@ RequestDetailsTypeDef = TypedDict(
     total=False,
 )
 
+ResponseDetailsTypeDef = TypedDict(
+    "ResponseDetailsTypeDef",
+    {
+        "ExportAssetToSignedUrl": "ExportAssetToSignedUrlResponseDetailsTypeDef",
+        "ExportAssetsToS3": "ExportAssetsToS3ResponseDetailsTypeDef",
+        "ExportRevisionsToS3": "ExportRevisionsToS3ResponseDetailsTypeDef",
+        "ImportAssetFromSignedUrl": "ImportAssetFromSignedUrlResponseDetailsTypeDef",
+        "ImportAssetsFromS3": "ImportAssetsFromS3ResponseDetailsTypeDef",
+    },
+    total=False,
+)
+
+_RequiredRevisionDestinationEntryTypeDef = TypedDict(
+    "_RequiredRevisionDestinationEntryTypeDef",
+    {
+        "Bucket": str,
+        "RevisionId": str,
+    },
+)
+_OptionalRevisionDestinationEntryTypeDef = TypedDict(
+    "_OptionalRevisionDestinationEntryTypeDef",
+    {
+        "KeyPattern": str,
+    },
+    total=False,
+)
+
+
+class RevisionDestinationEntryTypeDef(
+    _RequiredRevisionDestinationEntryTypeDef, _OptionalRevisionDestinationEntryTypeDef
+):
+    pass
+
+
+_RequiredRevisionEntryTypeDef = TypedDict(
+    "_RequiredRevisionEntryTypeDef",
+    {
+        "Arn": str,
+        "CreatedAt": datetime,
+        "DataSetId": str,
+        "Id": str,
+        "UpdatedAt": datetime,
+    },
+)
+_OptionalRevisionEntryTypeDef = TypedDict(
+    "_OptionalRevisionEntryTypeDef",
+    {
+        "Comment": str,
+        "Finalized": bool,
+        "SourceId": str,
+    },
+    total=False,
+)
+
+
+class RevisionEntryTypeDef(_RequiredRevisionEntryTypeDef, _OptionalRevisionEntryTypeDef):
+    pass
+
+
+S3SnapshotAssetTypeDef = TypedDict(
+    "S3SnapshotAssetTypeDef",
+    {
+        "Size": float,
+    },
+)
+
 UpdateAssetResponseTypeDef = TypedDict(
     "UpdateAssetResponseTypeDef",
     {
@@ -593,7 +718,7 @@ UpdateDataSetResponseTypeDef = TypedDict(
         "Description": str,
         "Id": str,
         "Name": str,
-        "Origin": Literal["OWNED", "ENTITLED"],
+        "Origin": Origin,
         "OriginDetails": "OriginDetailsTypeDef",
         "SourceId": str,
         "UpdatedAt": datetime,
